@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "languagetool" "1.3.1"
+(define-package "languagetool" "20250924.1813"
   "LanguageTool integration for grammar and spell check."
   '((emacs "27.1"))
   :url "https://github.com/PillFall/Emacs-LanguageTool.el"
-  :commit "8e697f43d1a55356983c93be2a0f314dcf86ca20"
-  :revdesc "v1.3.1-0-g8e697f43d1a5"
+  :commit "fa3c08c369bf53f3311f1f365b54271cf126e4dd"
+  :revdesc "fa3c08c369bf"
   :keywords '("grammar" "text" "docs" "tools" "convenience" "checker")
   :authors '(("Joar Buitrago" . "jebuitragoc@unal.edu.co"))
   :maintainers '(("Joar Buitrago" . "jebuitragoc@unal.edu.co")))
